#!/bin/bash
# Download and install RepRap software and additional components on Debian/Ubuntu/derivatives

# Get Arduino package and JRE, RXTX library, JDK as dependencies
apt-get -y install arduino

# Download and unpack software for Sanguino as Arduino variant
wget --continue --directory-prefix=/tmp http://sanguino.googlecode.com/files/Sanguino-0018r2_1_4.zip
unzip -o /tmp/Sanguino-0018r2_1_4.zip Sanguino/* -d /usr/share/arduino/hardware

# Determine platform architecture
ARCH=`uname -m`

# Get 64-bit Java3D JNI library, if relevant
if [ $ARCH="x86_64" ]; then
	sudo apt-get -y install libjava3d-jni
fi

# Installation target directory
REPRAPDIR="/usr/local/reprap"
# Have it
mkdir -p $REPRAPDIR

# Download and unpack architecture relevant RepRap bundle; adjust
if [ $ARCH="x86_64" ]; then
	wget --continue --content-disposition --directory-prefix=/tmp http://sourceforge.net/projects/reprap64bit/files/reprap%2064bit-mendel-20100719.zip/download
	unzip -o /tmp/reprap\ 64bit-mendel-20100719.zip -d /tmp
	cp -auf /tmp/Reprap/* $REPRAPDIR
	rm -rf /tmp/Reprap
	cd $REPRAPDIR
	ln -sf /usr/lib/jni/libj3dcore-ogl.so .
	ln -sf /usr/lib/jni/librxtxParallel.so .
	ln -sf /usr/lib/jni/librxtxSerial.so .
	chmod +x reprap
else
	wget --continue --content-disposition --directory-prefix=/tmp http://sourceforge.net/projects/reprap/files/reprap-mendel-20100806.zip/download
	unzip -o /tmp/reprap-mendel-20100806.zip -d /tmp
	cp -auf /tmp/reprap-mendel-20100806/* $REPRAPDIR
	rm -rf /tmp/reprap-mendel-20100806
fi

# Create startup script
REPRAP="/usr/local/bin/reprap"
echo '#!/bin/sh' > $REPRAP && echo "cd $REPRAPDIR" >> $REPRAP && echo "./reprap &" >> $REPRAP && chmod +x $REPRAP

# Announce finish
echo "RepRap install finished"
